@@ -1,9 +1,10 @@
 # __main__.py
 
 import pandasklar as pak
+from importlib.metadata import version
 
 def main():
-    print('pandasklar Hello World')
+    print('Hello pandasklar', version('pandasklar') )
 
     
 if __name__ == "__main__":
